#[non_exhaustive]pub enum StructuredOutputErrorKind {
MissingText,
Refusal,
InvalidOutput,
}Expand description
Stable category for local structured-output validation failures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingText
The response contained no model-visible text.
Refusal
The provider returned an explicit refusal instead of structured data.
InvalidOutput
The textual response was not valid for the requested Rust type.