pub struct ArtifactResolvingModel<M, S> { /* private fields */ }Expand description
Model decorator that resolves lazy artifact references immediately before provider transport while keeping transcripts and checkpoints reference-only.
Implementations
Sourceimpl<M, S> ArtifactResolvingModel<M, S>
impl<M, S> ArtifactResolvingModel<M, S>
Sourcepub fn new(inner: M, scope: ArtifactScope, store: S) -> Self
pub fn new(inner: M, scope: ArtifactScope, store: S) -> Self
Wraps a model with an artifact store.
Sourcepub const fn with_max_artifact_bytes(self, limit: usize) -> Self
pub const fn with_max_artifact_bytes(self, limit: usize) -> Self
Replaces the maximum resolved artifact size.